@@ -1,6 +1,6 @@
 package Yukki::Web::View::Attachment;
 BEGIN {
-  $Yukki::Web::View::Attachment::VERSION = '0.111720';
+  $Yukki::Web::View::Attachment::VERSION = '0.111830';
 }
 use 5.12.1;
 use Moose;
@@ -27,6 +27,23 @@ sub rename {
 }
 
 
+sub remove {
+    my ($self, $ctx, $vars) = @_;
+    my $file = $vars->{file};
+
+    $ctx->response->page_title($vars->{title});
+
+    return $self->render_page(
+        template => 'attachment/remove.html',
+        context  => $ctx,
+        vars     => {
+            '.yukkiname'          => $vars->{page},
+            '#cancel_remove@href' => $vars->{return_link},
+        },
+    );
+}
+
+
 
 __END__
 =pod
@@ -37,7 +54,7 @@ Yukki::Web::View::Attachment - View for attachment forms
 
 =head1 VERSION
 
-version 0.111720
+version 0.111830
 
 =head1 DESCRIPTION
 
@@ -49,6 +66,10 @@ Handles the display of attachment forms.
 
 Show the rename form for attachments.
 
+=head2 remove
+
+Show the remove form for attachmensts.
+
 =head1 AUTHOR
 
 Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
